# Generated by Django 4.1.7 on 2023-06-04 12:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('project_center', '0010_delete_activity_project_last_activity_date_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='project',
            name='last_activity_name',
            field=models.CharField(blank=True, default=None, help_text='Last Activity Name', max_length=255, null=True, verbose_name='Last Activity Name'),
        ),
    ]
